"""
This package contains asynchronous wrappers for the following object storage
provider APIs

- Backblaze B2 Cloud Storage

It is for internal usage only.
"""
PROVIDERS = ('backblaze', )

__all__ = ['PROVIDERS']
